@@ -6,12 +6,17 @@ log = logging.getLogger(__name__)
 
 from decimal import Decimal
 
-from twisted.internet import reactor
 from twisted.web.client import Agent
 from twisted.web.http_headers import Headers
 from twisted.internet import defer
 from twisted.protocols.basic import LineReceiver
 
+from pycnb import version
+
+RATES_URL = 'http://www.cnb.cz/cs/financni_trhy/devizovy_trh/kurzy_devizoveho_trhu/denni_kurz.txt'
+
+USER_AGENT = 'PyCNB ({0})'.format(version)
+
 class DailyRatesProtocol(LineReceiver):
     delimiter = '\n'
 
@@ -33,21 +38,17 @@ class DailyRatesProtocol(LineReceiver):
     def connectionLost(self, reason):
         self.deferred.callback(self.rates)
 
-def get_rates(cb):
+def get_rates(reactor):
     agent = Agent(reactor)
-    url = 'http://www.cnb.cz/cs/financni_trhy/devizovy_trh/kurzy_devizoveho_trhu/denni_kurz.txt'
-
+    url = RATES_URL
     d = agent.request(
         'GET',
         url,
-        Headers({'User-Agent': ['PyCNB']}))
+        Headers({'User-Agent': [USER_AGENT]}))
 
     drp = DailyRatesProtocol()
-    drp.deferred.addCallback(cb)
 
     d.addCallback(lambda r: r.deliverBody(drp))
     d.addCallback(lambda _: drp.deferred)
     d.addErrback(log.error)
-    d.addBoth(lambda x: reactor.stop())
-
-    reactor.run()
+    return d
